# SimpleCAD API 测试目录

## 当前测试结构

### 主要测试文件
- `comprehensive_test.py` - **主要测试文件**，包含所有核心功能的全面测试
  - 基础建模操作（拉伸、旋转、放样、扫掠）
  - 高级操作（阵列、圆角、倒角、抽壳）
  - 布尔运算（并、减、交）
  - 螺旋扫掠（圆形、螺纹齿形、三角形截面）
  - 复杂零件构建（法兰、齿轮、装配体）
  - 坐标系操作测试

### 运行测试

运行主要测试：
```bash
cd /Users/lildino/Project/SimpleCADAPI
python test/comprehensive_test.py
```

### 测试输出

测试将在 `output/` 目录中生成大量STL和STEP文件，包括：
- 基础建模操作示例（01-16）
- 高级操作示例（17-22）
- 布尔运算示例（23-27）
- 复杂零件（28-30）
- 坐标系验证（31-34）
- 螺旋扫掠示例（35-41）
- 验证测试（42-45）

### 测试特色

1. **螺旋扫掠测试**：
   - 圆形截面螺旋
   - 螺纹齿形截面螺旋
   - 三角形截面螺旋
   - 所有螺旋都是3圈设计

2. **复杂零件构建**：
   - 带多个螺栓孔的法兰
   - 简化齿轮
   - 多组件装配体

3. **坐标系验证**：
   - 嵌套坐标系
   - 旋转坐标系
   - Z轴方向验证

## 历史测试文件

### archive/ 目录
旧的测试文件已移动到 `archive/` 目录：
- `test_basic.py` - 基础功能测试
- `test_suite.py` - 旧的测试套件
- `examples.py` - API使用示例
- `array_fix_verification.py` - 阵列修复验证
- `test_loft_fix.py` - 放样修复测试
- `test_new_arrays.py` - 新阵列功能测试

这些文件保留作为参考，但主要推荐使用 `comprehensive_test.py`。

## 测试覆盖范围

✅ **已覆盖功能**：
- [x] 基础几何创建（点、线、草图）
- [x] 便利函数（矩形、圆形、立方体、圆柱体、球体）
- [x] 拉伸操作（普通、方向性）
- [x] 旋转操作（全圆、部分旋转）
- [x] 放样操作（多截面、复杂形状）
- [x] 扫掠操作（直线、曲线、复杂路径）
- [x] **螺旋扫掠（Profile-based API）**
- [x] 布尔运算（并、减、交、复杂组合）
- [x] 高级操作（阵列、圆角、倒角、抽壳）
- [x] 坐标系操作（嵌套、旋转、验证）
- [x] 文件导出（STL、STEP）
- [x] 复杂零件构建
- [x] 装配体操作

## 性能和质量

测试设计注重：
- **实用性**：测试真实世界的建模场景
- **全面性**：覆盖API的所有主要功能
- **可视化**：生成大量可视化模型文件
- **错误处理**：测试边界条件和异常情况
- **文档化**：每个测试都有清晰的说明

## 维护建议

1. 主要使用 `comprehensive_test.py` 进行功能验证
2. 新功能测试可直接添加到 `comprehensive_test.py` 中
3. 保持测试输出文件的命名规范
4. 定期清理 `output/` 目录中的测试文件
5. 重要模型同时导出STL和STEP格式
